@@ -1,7 +1,7 @@
 package CSS::DOM::Interface;
 
 use Exporter 5.57 'import';
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 require CSS::DOM::Constants;
 
@@ -11,7 +11,7 @@ CSS::DOM::Interface - A list of CSS::DOM's interface members in machine-readable
 
 =head1 VERSION
 
-Version 0.10
+Version 0.11
 
 =head1 SYNOPSIS
 
@@ -280,6 +280,7 @@ gory details, look at the source code. In fact, here it is:
   		maxWidth => STR,
   		minHeight => STR,
   		minWidth => STR,
+  		opacity => STR,
   		orphans => STR,
   		outline => STR,
   		outlineColor => STR,
@@ -375,9 +376,9 @@ gory details, look at the source code. In fact, here it is:
   			CSS::DOM::Value::Primitive::CSS_RGBCOLOR
   		]],
   		primitiveType => NUM | READONLY,
-  #		setFloatValue => METHOD | VOID,
+  		setFloatValue => METHOD | VOID,
   		getFloatValue => METHOD | NUM,
-  #		setStringValue => METHOD | VOID,
+  		setStringValue => METHOD | VOID,
   #		getStringValue => METHOD | STR,
   #		getCounterValue => METHOD | OBJ,
   #		getRectValue => METHOD | OBJ,
